@@ -25,109 +25,16 @@ from mpl_plotter.resources.functions import print_color
 
 class plot:
 
-    def init(self):
-        if not isinstance(self.backend, type(None)):
-            try:
-                mpl.use(self.backend)
-            except AttributeError:
-                raise AttributeError('{} backend not supported with current Python configuration'.format(self.backend))
+    def method_setup(self):
+        if isinstance(self.fig, type(None)):
+            if not self.plt.get_fignums():
+                self.method_figure()
+            else:
+                self.fig = self.plt.gcf()
+                self.ax = self.plt.gca()
 
-        # matplotlib.use() must be called *before* pylab, matplotlib.pyplot,
-        # or matplotlib.backends is imported for the first time.
-
-        self.plt = import_module("matplotlib.pyplot")
-
-        """
-        Run
-        """
-
-        self.run()
-
-    def run(self):
-
-        self.method_setup()
-
-        self.method_style()
-
-        # Mock plot
-        self.mock()
-
-        # Main
-        self.main()
-
-        # Colorbar
-        self.method_cb()
-
-        # Legend
-        self.method_legend()
-
-        # Resize axes
-        self.method_resize_axes()
-
-        # Makeup
-        self.method_background_alpha()
-        self.method_title()
-        self.method_axis_labels()
-        self.method_spines()
-        self.method_ticks()
-        self.method_grid()
-
-        # Save
-        self.method_save()
-
-        self.method_show()
-
-        return self.ax
-
-    def init_run_hm(self):
-
-        if not isinstance(self.backend, type(None)):
-            try:
-                mpl.use(self.backend)
-            except AttributeError:
-                raise AttributeError('{} backend not supported with current Python configuration'.format(self.backend))
-
-        # matplotlib.use() must be called *before* pylab, matplotlib.pyplot,
-        # or matplotlib.backends is imported for the first time.
-
-        self.plt = import_module("matplotlib.pyplot")
-
-        """
-        Run
-        """
-
-        self.method_setup()
-
-        self.method_style()
-
-        # Mock plot
-        self.mock()
-
-        # Main
-        self.main()
-
-        # Colorbar
-        self.method_cb()
-
-        # Makeup
-        self.method_background_alpha()
-        self.method_title()
-        self.method_axis_labels()
-        self.method_spines()
-        self.method_ticks()
-        self.method_grid()
-
-        # Save
-        self.method_save()
-
-        self.method_show()
-
-        return self.ax
-
-    def method_figure(self):
-        if not isinstance(self.style, type(None)):
-            self.plt.style.use(self.style)
-        self.fig = self.plt.figure(figsize=self.figsize)
+        if isinstance(self.ax, type(None)):
+            self.ax = self.fig.add_subplot(self.shape_and_position, adjustable='box')
 
     def method_style(self):
         if self.light:
@@ -148,19 +55,11 @@ class plot:
         self.ax.set_facecolor(self.background_color_plot)
         self.fig.patch.set_facecolor(self.background_color_figure)
 
-    def method_setup(self):
-        if isinstance(self.fig, type(None)):
-            if not self.plt.get_fignums():
-                self.method_figure()
-            else:
-                self.fig = self.plt.gcf()
-                self.ax = self.plt.gca()
-
-        if isinstance(self.ax, type(None)):
-            self.ax = self.fig.add_subplot(self.shape_and_position, adjustable='box')
-
     def method_cb(self):
         if self.color_bar is True:
+            if isinstance(self.norm, type(None)):
+                return print_color("No norm selected for colorbar. Set norm=<parameter of choice>", "grey")
+
             # Obtain and apply limits
             if isinstance(self.cb_vmin, type(None)):
                 self.cb_vmin = self.norm.min()
@@ -277,17 +176,6 @@ class plot:
             self.ax.set_ylim(self.y_lower_bound - self.y_lower_resize_pad,
                              self.y_upper_bound + self.y_upper_resize_pad)
 
-    def method_save(self):
-        if self.filename:
-            self.plt.savefig(self.filename, dpi=self.dpi)
-
-    def method_show(self):
-        if self.more_subplots_left is not True:
-            self.fig.tight_layout()
-            self.plt.show()
-        else:
-            print('Ready for next subplot')
-
     def method_background_alpha(self):
         self.ax.patch.set_alpha(1)
 
@@ -422,8 +310,187 @@ class plot:
         if self.grid is not False:
             self.plt.grid(linestyle=self.grid_lines, color=self.grid_color)
 
+    def method_save(self):
+        if self.filename:
+            self.plt.savefig(self.filename, dpi=self.dpi)
 
-class line(plot):
+    def method_show(self):
+        if self.more_subplots_left is not True:
+            self.fig.tight_layout()
+            self.plt.show()
+        else:
+            print('Ready for next subplot')
+
+    def method_figure(self):
+        if not isinstance(self.style, type(None)):
+            self.plt.style.use(self.style)
+        self.fig = self.plt.figure(figsize=self.figsize)
+
+
+class regular():
+
+    def init(self):
+        if not isinstance(self.backend, type(None)):
+            try:
+                mpl.use(self.backend)
+            except AttributeError:
+                raise AttributeError('{} backend not supported with current Python configuration'.format(self.backend))
+
+        # matplotlib.use() must be called *before* pylab, matplotlib.pyplot,
+        # or matplotlib.backends is imported for the first time.
+
+        self.plt = import_module("matplotlib.pyplot")
+
+        """
+        Run
+        """
+
+        self.run()
+
+    def run(self):
+
+        self.method_setup()
+
+        self.method_style()
+
+        # Mock plot
+        self.mock()
+
+        # Main
+        self.main()
+
+        # Colorbar
+        self.method_cb()
+
+        # Legend
+        self.method_legend()
+
+        # Resize axes
+        self.method_resize_axes()
+
+        # Makeup
+        self.method_background_alpha()
+        self.method_title()
+        self.method_axis_labels()
+        self.method_spines()
+        self.method_ticks()
+        self.method_grid()
+
+        # Save
+        self.method_save()
+
+        self.method_show()
+
+        return self.ax
+
+
+class plot_df:
+
+    def init(self):
+        if not isinstance(self.backend, type(None)):
+            try:
+                mpl.use(self.backend)
+            except AttributeError:
+                raise AttributeError('{} backend not supported with current Python configuration'.format(self.backend))
+
+        # matplotlib.use() must be called *before* pylab, matplotlib.pyplot,
+        # or matplotlib.backends is imported for the first time.
+
+        self.plt = import_module("matplotlib.pyplot")
+
+        """
+        Run
+        """
+
+        self.run()
+
+    def run(self):
+
+        self.method_setup()
+
+        self.method_style()
+
+        # Mock plot
+        self.mock()
+
+        # Main
+        self.main()
+
+        # Colorbar
+        self.method_cb()
+
+        # Makeup
+        self.method_background_alpha()
+        self.method_title()
+        self.method_axis_labels()
+        self.method_spines()
+        self.method_ticks()
+        self.method_grid()
+
+        # Save
+        self.method_save()
+
+        self.method_show()
+
+        return self.ax
+
+    def method_resize_axes_coordinates(self):
+        if self.resize_axes is True:
+            if isinstance(self.x_upper_bound, type(None)):
+                self.x_upper_bound = self.x.max()
+            else:
+                self.x_upper_resize_pad = 0
+            if isinstance(self.x_lower_bound, type(None)):
+                self.x_lower_bound = self.x.min()
+            else:
+                self.x_lower_resize_pad = 0
+
+            if isinstance(self.y_upper_bound, type(None)):
+                self.y_upper_bound = self.y.max()
+            else:
+                self.y_upper_resize_pad = 0
+            if isinstance(self.y_lower_bound, type(None)):
+                self.y_lower_bound = self.y.min()
+            else:
+                self.y_lower_resize_pad = 0
+
+            if isinstance(self.x_upper_resize_pad, type(None)):
+                self.x_upper_resize_pad = 0.05*(self.x_upper_bound-self.x_lower_bound)
+            if isinstance(self.x_lower_resize_pad, type(None)):
+                self.x_lower_resize_pad = 0.05*(self.x_upper_bound-self.x_lower_bound)
+            if isinstance(self.y_upper_resize_pad, type(None)):
+                self.y_upper_resize_pad = 0.05*(self.y_upper_bound-self.y_lower_bound)
+            if isinstance(self.y_lower_resize_pad, type(None)):
+                self.y_lower_resize_pad = 0.05*(self.y_upper_bound-self.y_lower_bound)
+
+            if not isinstance(self.aspect, type(None)):
+                self.ax.set_aspect(self.aspect)
+
+            self.ax.set_xbound(lower=self.x_lower_bound - self.x_lower_resize_pad,
+                               upper=self.x_upper_bound + self.x_upper_resize_pad)
+            self.ax.set_ybound(lower=self.y_lower_bound - self.y_lower_resize_pad,
+                               upper=self.y_upper_bound + self.y_upper_resize_pad)
+
+            self.ax.set_xlim(self.x_lower_bound - self.x_lower_resize_pad, self.x_upper_bound + self.x_upper_resize_pad)
+            self.ax.set_ylim(self.y_lower_bound - self.y_lower_resize_pad, self.y_upper_bound + self.y_upper_resize_pad)
+
+    def method_resize_axes_dataframe(self):
+        if not isinstance(self.z, type(pd.DataFrame)):
+            xmin = 0
+            ymin = 0
+            xmax = self.z.shape[0]
+            ymax = self.z.shape[1]
+            if self.resize_axes is True and isinstance(self.x_upper_bound, type(None)):
+                self.x_upper_bound = xmax
+            if self.resize_axes is True and isinstance(self.x_lower_bound, type(None)):
+                self.x_lower_bound = xmin
+            if self.resize_axes is True and isinstance(self.y_upper_bound, type(None)):
+                self.y_upper_bound = ymax
+            if self.resize_axes is True and isinstance(self.y_lower_bound, type(None)):
+                self.y_lower_bound = ymin
+
+
+class line(plot, regular):
 
     def __init__(self,
                  # Specifics
@@ -627,11 +694,11 @@ class line(plot):
             self.x, self.y = MockData().spirograph()
 
 
-class scatter(plot):
+class scatter(plot, regular):
 
     def __init__(self,
                  # Specifics
-                 point_size=5, marker='o', c=None,
+                 point_size=5, marker='o',
                  # Base
                  x=None, y=None,
                  backend='Qt5Agg', plot_label='Plot', font='serif',
@@ -652,7 +719,7 @@ class scatter(plot):
                  # Grid
                  grid=False, grid_color='black', grid_lines='-.',
                  # Color
-                 color=None, cmap='RdBu_r', alpha=None, norm=None,
+                 color="C0", cmap='RdBu_r', alpha=None, norm=None,
                  # Title
                  title='Title', title_bold=False, title_size=12, title_y=1.025,
                  # Labels
@@ -681,142 +748,143 @@ class scatter(plot):
                  # Save
                  filename=None, dpi=None,
                  ):
-            """
-            @param x:
-            @param y:
-            @param backend:
-            @param fig:
-            @param ax:
-            @param figsize:
-            @param shape_and_position:
-            @param font:
-            @param background_color_figure:
-            @param background_color_plot:
-            @param style:
-            @param light:
-            @param dark:
-            @param zorder:
-            @param x_upper_bound:
-            @param x_lower_bound:
-            @param y_upper_bound:
-            @param y_lower_bound:
-            @param x_bounds:
-            @param y_bounds:
-            @param x_upper_resize_pad:
-            @param x_lower_resize_pad:
-            @param y_upper_resize_pad:
-            @param y_lower_resize_pad:
-            @param color:
-            @param workspace_color:
-            @param workspace_color2:
-            @param alpha:
-            @param norm:
-            @param c:
-            @param point_size:
-            @param marker:
-            @param label:
-            @param legend:
-            @param legend_loc:
-            @param legend_size:
-            @param legend_weight:
-            @param legend_style:
-            @param legend_handleheight:
-            @param legend_ncol:
-            @param grid:
-            @param grid_color:
-            @param grid_lines:
-            @param spines_removed:
-            @param cmap:
-            @param color_bar:
-            @param cb_pad:
-            @param extend:
-            @param cb_title:
-            @param cb_orientation:
-            @param cb_axis_labelpad:
-            @param cb_tick_number:
-            @param shrink:
-            @param cb_outline_width:
-            @param cb_title_rotation:
-            @param cb_title_style:
-            @param cb_title_size:
-            @param cb_top_title_y:
-            @param cb_ytitle_labelpad:
-            @param cb_title_weight:
-            @param cb_top_title:
-            @param cb_y_title:
-            @param cb_top_title_pad:
-            @param cb_top_title_x:
-            @param cb_vmin:
-            @param cb_vmax:
-            @param cb_ticklabelsize:
-            @param cb_hard_bounds:
-            @param prune:
-            @param resize_axes:
-            @param aspect:
-            @param title:
-            @param title_bold:
-            @param title_size:
-            @param title_y:
-            @param x_label:
-            @param x_label_bold:
-            @param x_label_size:
-            @param x_label_pad:
-            @param x_label_rotation:
-            @param y_label:
-            @param y_label_bold:
-            @param y_label_size:
-            @param y_label_pad:
-            @param y_label_rotation:
-            @param x_tick_number:
-            @param x_tick_labels:
-            @param y_tick_number:
-            @param y_tick_labels:
-            @param x_tick_rotation:
-            @param y_tick_rotation:
-            @param x_label_coords:
-            @param y_label_coords:
-            @param tick_color:
-            @param tick_label_pad:
-            @param tick_ndecimals:
-            @param tick_label_size:
-            @param tick_label_size_x:
-            @param tick_label_size_y:
-            @param more_subplots_left:
-            @param subplot:
-            @param filename:
-            @param dpi:
-            @param custom_x_tick_labels:
-            @param custom_y_tick_labels:
-            @param date_tick_labels_x:
-            @param date_format:
-            """
 
-            # Turn all instance arguments to instance attributes
-            for item in inspect.signature(scatter).parameters:
-                setattr(self, item, eval(item))
+        """
+        @param x:
+        @param y:
+        @param backend:
+        @param fig:
+        @param ax:
+        @param figsize:
+        @param shape_and_position:
+        @param font:
+        @param background_color_figure:
+        @param background_color_plot:
+        @param style:
+        @param light:
+        @param dark:
+        @param zorder:
+        @param x_upper_bound:
+        @param x_lower_bound:
+        @param y_upper_bound:
+        @param y_lower_bound:
+        @param x_bounds:
+        @param y_bounds:
+        @param x_upper_resize_pad:
+        @param x_lower_resize_pad:
+        @param y_upper_resize_pad:
+        @param y_lower_resize_pad:
+        @param color:
+        @param workspace_color:
+        @param workspace_color2:
+        @param alpha:
+        @param norm:
+        @param c:
+        @param point_size:
+        @param marker:
+        @param label:
+        @param legend:
+        @param legend_loc:
+        @param legend_size:
+        @param legend_weight:
+        @param legend_style:
+        @param legend_handleheight:
+        @param legend_ncol:
+        @param grid:
+        @param grid_color:
+        @param grid_lines:
+        @param spines_removed:
+        @param cmap:
+        @param color_bar:
+        @param cb_pad:
+        @param extend:
+        @param cb_title:
+        @param cb_orientation:
+        @param cb_axis_labelpad:
+        @param cb_tick_number:
+        @param shrink:
+        @param cb_outline_width:
+        @param cb_title_rotation:
+        @param cb_title_style:
+        @param cb_title_size:
+        @param cb_top_title_y:
+        @param cb_ytitle_labelpad:
+        @param cb_title_weight:
+        @param cb_top_title:
+        @param cb_y_title:
+        @param cb_top_title_pad:
+        @param cb_top_title_x:
+        @param cb_vmin:
+        @param cb_vmax:
+        @param cb_ticklabelsize:
+        @param cb_hard_bounds:
+        @param prune:
+        @param resize_axes:
+        @param aspect:
+        @param title:
+        @param title_bold:
+        @param title_size:
+        @param title_y:
+        @param x_label:
+        @param x_label_bold:
+        @param x_label_size:
+        @param x_label_pad:
+        @param x_label_rotation:
+        @param y_label:
+        @param y_label_bold:
+        @param y_label_size:
+        @param y_label_pad:
+        @param y_label_rotation:
+        @param x_tick_number:
+        @param x_tick_labels:
+        @param y_tick_number:
+        @param y_tick_labels:
+        @param x_tick_rotation:
+        @param y_tick_rotation:
+        @param x_label_coords:
+        @param y_label_coords:
+        @param tick_color:
+        @param tick_label_pad:
+        @param tick_ndecimals:
+        @param tick_label_size:
+        @param tick_label_size_x:
+        @param tick_label_size_y:
+        @param more_subplots_left:
+        @param subplot:
+        @param filename:
+        @param dpi:
+        @param custom_x_tick_labels:
+        @param custom_y_tick_labels:
+        @param date_tick_labels_x:
+        @param date_format:
+        """
 
-            self.init()
+        # Turn all instance arguments to instance attributes
+        for item in inspect.signature(scatter).parameters:
+            setattr(self, item, eval(item))
+
+        self.init()
 
     def main(self):
 
-        if not isinstance(self.color, type(None)):
+        if not isinstance(self.norm, type(None)):
             self.graph = self.ax.scatter(self.x, self.y, label=self.plot_label, s=self.point_size, marker=self.marker,
-                                         color=self.color,
+                                         c=self.norm, cmap=self.cmap,
                                          zorder=self.zorder,
                                          alpha=self.alpha)
-        if not isinstance(self.c, type(None)):
+        else:
             self.graph = self.ax.scatter(self.x, self.y, label=self.plot_label, s=self.point_size, marker=self.marker,
-                                         c=self.c, cmap=self.cmap,
+                                         color=self.color,
                                          zorder=self.zorder,
                                          alpha=self.alpha)
 
     def mock(self):
         if isinstance(self.x, type(None)) and isinstance(self.y, type(None)):
             self.x, self.y = MockData().spirograph()
-            self.c = self.y
+            self.norm = self.y
 
 
-class heatmap(plot):
+class heatmap(plot, plot_df):
 
     def __init__(self,
                  # Specifics
@@ -973,7 +1041,7 @@ class heatmap(plot):
             for item in inspect.signature(heatmap).parameters:
                 setattr(self, item, eval(item))
 
-            self.init_run_hm()
+            self.init()
 
     def main(self):
 
@@ -996,21 +1064,6 @@ class heatmap(plot):
         if isinstance(self.x, type(None)) and isinstance(self.y, type(None)):
             self.z = MockData().waterdropdf()
 
-    def method_resize_axes_dataframe(self):
-        if not isinstance(self.z, type(pd.DataFrame)):
-            xmin = 0
-            ymin = 0
-            xmax = self.z.shape[0]
-            ymax = self.z.shape[1]
-            if self.resize_axes is True and isinstance(self.x_upper_bound, type(None)):
-                self.x_upper_bound = xmax
-            if self.resize_axes is True and isinstance(self.x_lower_bound, type(None)):
-                self.x_lower_bound = xmin
-            if self.resize_axes is True and isinstance(self.y_upper_bound, type(None)):
-                self.y_upper_bound = ymax
-            if self.resize_axes is True and isinstance(self.y_lower_bound, type(None)):
-                self.y_lower_bound = ymin
-
 
 class quiver(plot):
 
